(************************************************************************
*    This File is Part of the AHM Triton Tools                          *
*    for Borland Delphi and C++ Builder.                                *
*************************************************************************
* Copyright  1995-2000 Alexander H. Mehlhorn (AHM) and Tritontools.com *
* All Rights reserved.                                                  *
*                                                                       *
*    For more Information contact us at                                 *
*    E-Mail : support@tritontools.com                                   *
*    URL : http://www.tritontools.com                                   *
*                                                                       *
*    AHM is copyright by Alexander H. Mehlhorn                          *
*    All Parts of this Collection were developed,                       *
*    designed and implemented by AHM                                    *
*                                                                       *
*    Under no Circumstances may you distribute this file                *
*    in this or any other format. This File is supplied                 *
*    as Evaluation of Source only. No Delphi Components may be developed*
*    using extracts or subsets of this code without expressed permission*
*    by AHM.                                                            *
*                                                                       *
*************************************************************************)
unit AHMTBevel;

interface

uses Windows, Classes, Graphics, ExtCtrls,AHMFreeware;

type
  TAHMBevel = class(TBevel)
  private
    FAbout : TAHMAboutFreeStr;
    FHighlight,FShadow : TColor;
    procedure SetHighlight(value : TColor);
    procedure SetShadow(value : TColor);
  protected
  public
    constructor Create(AOwner: TComponent); override;
    procedure Paint; override;
  published
    Property About : TAHMAboutFreeStr read FAbout write FAbout;
    property Align;
    property Highlight : TColor read FHighlight write setHighlight default clbtnHighlight;
    Property Shadow : TColor read FShadow write setShadow default clbtnShadow;
    property ParentShowHint;
    property Shape;
    property ShowHint;
    property Style;
    property Visible;
  end;

implementation

procedure TAHMBevel.SetHighlight(value : tColor);
begin
  FHighlight:=value;
  invalidate;
end;

procedure TAHMBevel.SetShadow(value : tColor);
begin
  FShadow:=value;
  invalidate;
end;

constructor TAHMBevel.Create(AOwner: TComponent);
begin
  inherited create(AOwner);
  FHighlight:=clwhite;
  FShadow:=clblack;
end;

procedure TAHMBevel.Paint;
var
  Color1, Color2: TColor;
  Temp: TColor;
procedure BevelRect(const R: TRect);
begin
  with Canvas do
  begin
    Pen.Color := Color1;
    PolyLine([Point(R.Left, R.Bottom), Point(R.Left, R.Top),Point(R.Right, R.Top)]);
    Pen.Color := Color2;
    PolyLine([Point(R.Right, R.Top), Point(R.Right, R.Bottom),Point(R.Left, R.Bottom)]);
  end;
end;
procedure BevelLine(C: TColor; X1, Y1, X2, Y2: Integer);
begin
  with Canvas do
  begin
    Pen.Color := C;
    MoveTo(X1, Y1);
    LineTo(X2, Y2);
  end;
end;
begin
  with Canvas do
  begin
    Pen.Width := 1;
    if Style = bsLowered then
    begin
      Color1 := FShadow;
      Color2 := FHighlight;
    end else
    begin
      Color1 := FHighlight;
      Color2 := FShadow;
    end;
    case Shape of
      bsBox: BevelRect(Rect(0, 0, Width - 1, Height - 1));
      bsFrame:
      begin
        Temp := Color1;
        Color1 := Color2;
        BevelRect(Rect(1, 1, Width - 1, Height - 1));
        Color2 := Temp;
        Color1 := Temp;
        BevelRect(Rect(0, 0, Width - 2, Height - 2));
      end;
      bsTopLine:
      begin
        BevelLine(Color1, 0, 0, Width, 0);
        BevelLine(Color2, 0, 1, Width, 1);
      end;
      bsBottomLine:
      begin
        BevelLine(Color1, 0, Height - 2, Width, Height - 2);
        BevelLine(Color2, 0, Height - 1, Width, Height - 1);
      end;
      bsLeftLine:
      begin
        BevelLine(Color1, 0, 0, 0, Height);
        BevelLine(Color2, 1, 0, 1, Height);
      end;
      bsRightLine:
      begin
        BevelLine(Color1, Width - 2, 0, Width - 2, Height);
        BevelLine(Color2, Width - 1, 0, Width - 1, Height);
      end;
    end;
  end;
end;

end.
