(************************************************************************
*    This File is Part of the AHM Triton Tools                          *
*    for Borland Delphi and C++ Builder.                                *
*************************************************************************
* Copyright  1995-2000 Alexander H. Mehlhorn (AHM) and Tritontools.com *
* All Rights reserved.                                                  *
*                                                                       *
*    For more Information contact us at                                 *
*    E-Mail : support@tritontools.com                                   *
*    URL : http://www.tritontools.com                                   *
*                                                                       *
*    AHM is copyright by Alexander H. Mehlhorn                          *
*    All Parts of this Collection were developed,                       *
*    designed and implemented by AHM                                    *
*                                                                       *
*    Under no Circumstances may you distribute this file                *
*    in this or any other format. This File is supplied                 *
*    as Evaluation of Source only. No Delphi Components may be developed*
*    using extracts or subsets of this code without expressed permission*
*    by AHM.                                                            *
*                                                                       *
*************************************************************************)
unit AHMTLogWindow;

interface

uses
  Windows, Messages, SysUtils, Classes, Graphics, Controls, Forms, Dialogs,
  ExtCtrls, ComCtrls, StdCtrls, Menus,Printers,AHMfreeware;

type
  TAHMLogWindowForm = class(TForm)
    RichEdit1: TRichEdit;
    MainMenu1: TMainMenu;
    File1: TMenuItem;
    Edit1: TMenuItem;
    New1: TMenuItem;
    Open1: TMenuItem;
    Save1: TMenuItem;
    N1: TMenuItem;
    Print1: TMenuItem;
    N2: TMenuItem;
    Exit1: TMenuItem;
    WordWrap1: TMenuItem;
    PrintDialog1: TPrintDialog;
    OpenDialog1: TOpenDialog;
    SaveDialog1: TSaveDialog;
    Font1: TMenuItem;
    N3: TMenuItem;
    FontDialog1: TFontDialog;
    Background1: TMenuItem;
    ColorDialog1: TColorDialog;
    procedure Print1Click(Sender: TObject);
    procedure New1Click(Sender: TObject);
    procedure Open1Click(Sender: TObject);
    procedure Save1Click(Sender: TObject);
    procedure Font1Click(Sender: TObject);
    procedure WordWrap1Click(Sender: TObject);
    procedure Exit1Click(Sender: TObject);
    procedure Background1Click(Sender: TObject);
  private
  public
    aexit,aopen,asave : TNotifyevent;
  end;

type
  TAHMLogWindow = class(TComponent)
  private
    FAbout : TAHMAboutFreeStr;
     fedcap,ffil : String;
     fbcol : Tcolor;
     fonsave,fonexit,fonexec : TNotifyevent;
     ffon : Tfont;
     dN1,fload : Boolean;
     fwpos : TPosition;
     fheight,fwidth : Integer;
     fbord : TBorderIcons;
     freado : Boolean;
     fico : TIcon;
     fwstate : TWindowstate;
     Procedure Setfont(value: Tfont);
     Procedure SetMenuFile(value : Boolean);
     Procedure SetBordericons(value : Tbordericons);
     Procedure SetIco(value : TIcon);
  protected
  public
    constructor Create( AOwner: TComponent ); override;
    destructor Destroy; override;
    Function execute : Boolean;
    procedure Log(value : string);
    procedure Clear;
  published
    Property About : TAHMAboutFreeStr read FAbout write FAbout;
    Property LogWindowCaption : String read fedcap write fedcap;
    Property LogWindowColor : TColor read fbcol write fbcol;
    Property LogWindowFonts : TFont read ffon write Setfont;
    Property FileMenu : Boolean read dN1 write SetMenuFile;
    Property OpenFilename : String read ffil write ffil;
    Property OpenFileOnExecute : Boolean read fload write fload;
    Property OnExecute : Tnotifyevent read fonexec write fonexec;
    Property OnExit : TNotifyevent read fonexit write fonexit;
    Property OnSaveFile : TNotifyevent read fonsave write fonsave;
    Property Windowstate : TWindowstate read fwstate write fwstate;
    Property WindowPosition : TPosition read fwpos write fwpos;
    Property BorderIcons : TBorderIcons read fbord write SetborderIcons;
    Property WindowWidth : Integer read fwidth write fwidth;
    Property WindowHeight : Integer read fheight write fheight;
    Property Readonly : Boolean read freado write freado;
    Property LogWindowIcon : TIcon read fico write SetIco;
  end;
var fvwf : TAHMLogWindowForm;

implementation
{$R *.DFM}

Constructor TAHMLogWindow.Create( AOwner: TComponent );
begin
  ffon := TFont.create;
  fico := TIcon.create;
  dN1:=true;
  fload:=false;
  fheight:=300; fwidth:=300;
  fbcol:=clwhite;
  inherited Create(AOwner);
end;

Destructor TAHMLogWindow.Destroy;
begin
  fico.free;
  ffon.free;
  inherited Destroy;
end;

Function TAHMLogWindow.execute : Boolean;
begin
  fvwf:=TAHMLogWindowForm.create(Application);
  with fvwf do
  try
   Windowstate:=wsNormal;
   Position:=poDesigned;
   Formstyle:=fsstayontop;
   refresh;
   caption:=fedcap;
   richedit1.font.assign(ffon);
   richedit1.color:=fbcol;
   File1.visible:=dN1;
   New1.visible:=dN1;
   Save1.visible:=dN1;
   Print1.visible:=dN1;
   Exit1.visible:=dN1;
   Edit1.visible:=false;
   Open1.visible:=false;
   N1.visible:=false;
   N2.visible:=false;
   richedit1.readonly:=freado;
   New1.Caption:='&Clear';
   if assigned(fonexec) then fonexec(self);
   aexit:=fonexit;
   width:=fwidth;
   height:=fheight;
   asave:=fonsave;
   fvwf.aopen:=nil;
   icon.assign(fico);
   Bordericons:=(fbord);
   Windowstate:=fwstate;
   Position:=fwpos;
    if fload=true then
    if ffil<>'' then
    begin
     if not(fileexists(ffil)) then showmessage('File to open does not exist')
     else richedit1.lines.loadfromfile(ffil);
    end
    else showmessage('Please specify a File to open');
    showmodal;
   finally
     fvwf.free;
  end;
  result:=true;  
end;

Procedure TAHMLogWindow.Log(value : String);
begin
  fvwf.richedit1.lines.add(value);
  fvwf.richedit1.refresh;
end;

Procedure TAHMLogWindow.SetIco(value : TIcon);
begin
  fico.assign(value);
end;

Procedure TAHMLogWindow.Clear;
begin
  fvwf.richedit1.lines.Clear;
end;

Procedure TAHMLogWindow.SetBordericons(value : TBordericons);
begin
  fbord:=(value);
end;

Procedure TAHMLogWindow.SetMenuFile(value:Boolean);
begin
  dN1:=value;
end;

Procedure TAHMLogWindow.SetFont(value : Tfont);
begin
  ffon.assign(value);
end;

procedure TAHMLogWindowForm.Print1Click(Sender: TObject);
var
  Line: Integer;
  PrintText: TextFile;
begin
  if PrintDialog1.Execute then
  begin
    AssignPrn(PrintText);
    Rewrite(PrintText);
    Printer.Canvas.Font := Richedit1.Font;
    for Line := 0 to Richedit1.Lines.Count - 1 do
       Writeln(PrintText, Richedit1.Lines[Line]);
    CloseFile(PrintText);
  end;
end;


procedure TAHMLogWindowForm.New1Click(Sender: TObject);
begin
  richedit1.lines.clear;
  caption:='';
end;


procedure TAHMLogWindowForm.Open1Click(Sender: TObject);
begin
  if opendialog1.execute then
  begin
    richedit1.lines.clear;
    richedit1.lines.loadfromfile(opendialog1.filename);
    caption:=opendialog1.filename;
    if assigned(aopen) then aopen(self);
  end;
  caption:=uppercase(caption);
end;


procedure TAHMLogWindowForm.Save1Click(Sender: TObject);
begin
  savedialog1.filename:=caption;
  if savedialog1.execute then
  begin
    richedit1.lines.savetofile(savedialog1.filename);
    caption:=savedialog1.filename;
    If assigned(asave) then asave(self);
  end;
  caption:=uppercase(caption);
end;


procedure TAHMLogWindowForm.Font1Click(Sender: TObject);
begin
  if fontdialog1.execute then
    richedit1.font:=fontdialog1.font;
end;


procedure TAHMLogWindowForm.WordWrap1Click(Sender: TObject);
begin
  if wordwrap1.checked=false then
  begin
    Wordwrap1.checked:=true;
    richedit1.wordwrap:=true;
  end
  else begin
    Wordwrap1.checked:=false;
    richedit1.wordwrap:=false;
  end;
end;


procedure TAHMLogWindowForm.Exit1Click(Sender: TObject);
begin
  if assigned(aexit) then aexit(self);
  close;
end;

procedure TAHMLogWindowForm.Background1Click(Sender: TObject);
begin
  If Colordialog1.execute then
    richedit1.color:=colordialog1.color;
end;

end.
